@@ -16,6 +16,7 @@ import struct as _struct
 from distutils.sysconfig import get_config_var as _get_config_var
 import re as _re
 import warnings
+import contextlib
 
 # Ensure that methods in this module get filtered in the tracebacks
 # from unittest
@@ -24,10 +25,51 @@ __unittest = False
 # Have a way to disable the autorelease pool behaviour
 _usepool = not _os.environ.get('PYOBJC_NO_AUTORELEASE')
 
+# Python 2/3 Compatibility for the PyObjC Test Suite
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    basestring
+except NameError:
+    basestring = str
+
+try:
+    bytes
+except NameError:
+    bytes = str
+
+try:
+    unichr
+except NameError:
+    unichr = chr
+
 def _typemap(tp): # XXX: Is this needed?
     if tp is None: return None
     return tp.replace(b'_NSRect', b'CGRect').replace(b'_NSPoint', b'CGPoint').replace(b'_NSSize', b'CGSize')
 
+@contextlib.contextmanager
+def pyobjc_options(**kwds):
+    orig = {}
+    try:
+        for k in kwds:
+            orig[k] = getattr(objc.options, k)
+            setattr(objc.options, k, kwds[k])
+
+        yield
+
+    finally:
+        for k in orig:
+            setattr(objc.options, k, orig[k])
+
+
 def sdkForPython(_cache=[]):
     """
     Return the SDK version used to compile Python itself,
@@ -119,16 +161,19 @@ def cast_ulonglong(value):
 _os_release = None
 def os_release():
     """
-    Returns '10.5' on all releases of Leopard, simularly for other
-    major releases.
+    Returns the release of macOS (for example 10.5.1).
     """
     global _os_release
     if _os_release is not None:
         return _os_release
 
-    pl = _pl.readPlist('/System/Library/CoreServices/SystemVersion.plist')
+    if hasattr(_pl, 'load'):
+        with open('/System/Library/CoreServices/SystemVersion.plist', 'rb') as fp:
+            pl = _pl.load(fp)
+    else:
+        pl = _pl.readPlist('/System/Library/CoreServices/SystemVersion.plist')
     v = pl['ProductVersion']
-    return '.'.join(v.split('.')[:2])
+    return '.'.join(v.split('.'))
 
 
 def is32Bit():
@@ -227,6 +272,47 @@ def min_python_release(version):
     parts = tuple(map(int, version.split('.')))
     return onlyIf(_sys.version_info[:2] >= parts, "Requires Python %s or later"%(version,))
 
+def _sort_key(version):
+    parts = version.split('.')
+    if len(parts) == 2:
+      parts.append('0')
+
+    if len(parts) != 3:
+       raise ValueError("Invalid version: %r"%(version,))
+
+    return tuple(int(x) for x in parts)
+
+
+def os_level_key(release):
+    """
+    Return an object that can be used to compare two releases.
+    """
+    return _sort_key(release)
+
+
+def min_sdk_level(release):
+    """
+    Usage::
+
+        class Tests (unittest.TestCase):
+            @min_sdk_level('10.6')
+            def testSnowLeopardSDK(self):
+                pass
+    """
+    v = (objc.PyObjC_BUILD_RELEASE // 100, objc.PyObjC_BUILD_RELEASE % 100, 0)
+    return onlyIf(v >= os_level_key(release), "Requires build with SDK %s or later"%(release,))
+
+def max_sdk_level(release):
+    """
+    Usage::
+
+        class Tests (unittest.TestCase):
+            @max_sdk_level('10.5')
+            def testUntilLeopardSDK(self):
+                pass
+    """
+    v = (objc.PyObjC_BUILD_RELEASE // 100, objc.PyObjC_BUILD_RELEASE % 100, 0)
+    return onlyIf(v <= os_level_key(release), "Requires build with SDK %s or later"%(release,))
 
 def min_os_level(release):
     """
@@ -238,7 +324,7 @@ def min_os_level(release):
             def testSnowLeopardCode(self):
                 pass
     """
-    return onlyIf(os_release() >= release, "Requires OSX %s or later"%(release,))
+    return onlyIf(os_level_key(os_release()) >= os_level_key(release), "Requires OSX %s or later"%(release,))
 
 def max_os_level(release):
     """
@@ -250,7 +336,7 @@ def max_os_level(release):
             def testUntilLeopard(self):
                 pass
     """
-    return onlyIf(os_release() <= release, "Requires OSX upto %s"%(release,))
+    return onlyIf(os_level_key(os_release()) <= os_level_key(release), "Requires OSX upto %s"%(release,))
 
 def os_level_between(min_release, max_release):
     """
@@ -262,7 +348,7 @@ def os_level_between(min_release, max_release):
             def testUntilLeopard(self):
                 pass
     """
-    return onlyIf(min_release <= os_release() <= max_release, "Requires OSX %s upto %s"%(min_release, max_release))
+    return onlyIf(os_level_key(min_release) <= os_level_key(os_release()) <= os_level_key(max_release), "Requires OSX %s upto %s"%(min_release, max_release))
 
 _poolclass = objc.lookUpClass('NSAutoreleasePool')
 
@@ -357,7 +443,7 @@ class TestCase (_unittest.TestCase):
     def assertResultIsVariableSize(self, method, message = None):
         info = method.__metadata__()
         if not info.get('retval', {}).get('c_array_of_variable_length', False):
-            self.fail(message or "result of %r is not a variable sized array"%(argno, method))
+            self.fail(message or "result of %r is not a variable sized array"%(method,))
 
     def assertArgSizeInResult(self, method, argno, message = None):
         if isinstance(method, objc.selector):
@@ -580,7 +666,7 @@ class TestCase (_unittest.TestCase):
         try:
             iface = st['retval']['type']
             if st['arguments'][0]['type'] != b'^v':
-                self.fail(message or "arg %d of %s has an invalid block signature"%(argno, method))
+                self.fail(message or "arg %d of %s has an invalid block signature %r"%(argno, method, st['arguments'][0]['type']))
             for a in st['arguments'][1:]:
                 iface += a['type']
         except KeyError:
@@ -609,7 +695,7 @@ class TestCase (_unittest.TestCase):
         try:
             iface = st['retval']['type']
             if st['arguments'][0]['type'] != b'^v':
-                self.fail(message or "result %s has an invalid block signature"%(method))
+                self.fail(message or "result %s has an invalid block signature %r"%(method, st['arguments'][0]['type']))
             for a in st['arguments'][1:]:
                 iface += a['type']
         except KeyError:
@@ -722,7 +808,7 @@ class TestCase (_unittest.TestCase):
             offset = 0
         info = method.__metadata__()
         type = info['arguments'][argno+offset]['type']
-        if not type.startswith(b'o^'):
+        if not type.startswith(b'o^') and not type.startswith(b'o*'):
             self.fail(message or "arg %d of %s is not an 'out' argument"%(
                 argno, method))
 
@@ -733,7 +819,7 @@ class TestCase (_unittest.TestCase):
             offset = 0
         info = method.__metadata__()
         type = info['arguments'][argno+offset]['type']
-        if not type.startswith(b'N^'):
+        if not type.startswith(b'N^') and not type.startswith(b'N*'):
             self.fail(message or "arg %d of %s is not an 'inout' argument"%(
                 argno, method))
 
@@ -744,7 +830,7 @@ class TestCase (_unittest.TestCase):
             offset = 0
         info = method.__metadata__()
         type = info['arguments'][argno+offset]['type']
-        if not type.startswith(b'n^'):
+        if not type.startswith(b'n^') and not type.startswith(b'n*'):
             self.fail(message or "arg %d of %s is not an 'in' argument"%(
                 argno, method))
 
@@ -936,16 +1022,3 @@ def expectedFailureIf(condition):
         return expectedFailure
     else:
         return lambda func: func
-
-# NOTE: filterwarnings relies on implementation details of
-#       the warnings module
-class filterWarnings (object):
-    def __init__(self, kind, category):
-        self._kind = kind
-        self._category = category
-
-    def __enter__(self):
-        warnings.filterwarnings(self._kind, category=self._category)
-
-    def __exit__(self, type, value, tp):
-        del warnings.filters[0]
