@@ -7,7 +7,7 @@
 {
     OC_PythonArray* res;
 
-    res = [[OC_PythonArray alloc] initWithPythonObject:v];
+    res = [[self alloc] initWithPythonObject:v];
     return [res autorelease];
 }
 
@@ -42,9 +42,18 @@
     return YES;
 }
 
++ (BOOL)supportsSecureCoding {
+    return NO;
+}
+
+
 -(oneway void)release
 {
     /* See comment in OC_PythonUnicode */
+    if (unlikely(!Py_IsInitialized())) {
+        [super release];
+        return;
+    }
     PyObjC_BEGIN_WITH_GIL
 
         [super release];
@@ -54,6 +63,10 @@
 
 -(void)dealloc
 {
+    if (unlikely(!Py_IsInitialized())) {
+        [super dealloc];
+        return;
+    }
     PyObjC_BEGIN_WITH_GIL
         PyObjC_UnregisterObjCProxy(value, self);
         Py_CLEAR(value);
@@ -340,7 +353,7 @@
     NSUInteger i;
     PyObjC_BEGIN_WITH_GIL
         if (PyTuple_CheckExact(value) && (NSUInteger)PyTuple_Size(value) == count) {
-            for  (i = 0; i < count; i++) {
+            for (i = 0; i < count; i++) {
                 PyObject* v;
 
                 if (objects[i] == [NSNull null]) {
@@ -366,7 +379,7 @@
 
         } else {
 
-            for  (i = 0; i < count; i++) {
+            for (i = 0; i < count; i++) {
                 PyObject* v;
                 int r;
 
@@ -381,7 +394,7 @@
                     PyObjC_GIL_FORWARD_EXC();
                 }
 
-                r = PyList_Append(value,  v);
+                r = PyList_Append(value, v);
                 if (r == -1) {
                     PyObjC_GIL_FORWARD_EXC();
                 }
