@@ -15,14 +15,16 @@
 
 - (OC_PythonData*)initWithPythonObject:(PyObject*)v
 {
-    Py_ssize_t buffer_len;
-    const void *buffer;
-
     self = [super init];
     if (unlikely(self == nil)) return nil;
 
-    if (unlikely(PyObject_AsReadBuffer(v, &buffer, &buffer_len) == -1)) {
-        [super dealloc];
+    if (!PyObject_CheckBuffer(v)
+#if PY_MAJOR_VERSION == 2
+        && !PyObject_CheckReadBuffer(v)
+#endif
+            ) {
+        PyErr_SetString(PyExc_TypeError, "not a buffer");
+        [self release];
         return nil;
     }
 
@@ -87,20 +89,30 @@
     NSUInteger rval;
 
     PyObjC_BEGIN_WITH_GIL
+#if PY_MAJOR_VERSION == 2
+      if (PyObject_CheckBuffer(value)) {
+#endif
+        OCReleasedBuffer* temp = [[OCReleasedBuffer alloc] initWithPythonBuffer:value writable:NO];
+        if (temp == nil) {
+            [self release];
+            PyErr_Clear();
+            return 0;
+        }
+        [temp release];
+        rval = [temp length];
+#if PY_MAJOR_VERSION == 2
+      } else {
         Py_ssize_t buffer_len;
         const void *buffer;
 
         if (unlikely(PyObject_AsReadBuffer(value, &buffer, &buffer_len) == -1)) {
+            [self release];
             PyErr_Clear();
-            rval = 0;
-
-        } else {
-            if ((NSUInteger)buffer_len > NSUIntegerMax) {
-                rval = NSUIntegerMax;
-            } else {
-                rval = buffer_len;
-            }
+            return 0;
         }
+        rval = buffer_len;
+      }
+#endif
 
     PyObjC_END_WITH_GIL
     return rval;
@@ -108,17 +120,35 @@
 
 -(const void *)bytes
 {
-    const void *rval;
+    void* rval;
+
     PyObjC_BEGIN_WITH_GIL
+#if PY_MAJOR_VERSION == 2
+      if (PyObject_CheckBuffer(value)) {
+#endif
+        OCReleasedBuffer* temp = [[OCReleasedBuffer alloc] initWithPythonBuffer:value writable:NO];
+        if (temp == nil) {
+            [self release];
+            PyErr_Clear();
+            return nil;
+        }
+        [temp autorelease];
+        rval = [temp buffer];
+
+#if PY_MAJOR_VERSION == 2
+      } else {
         Py_ssize_t buffer_len;
         const void *buffer;
 
         if (unlikely(PyObject_AsReadBuffer(value, &buffer, &buffer_len) == -1)) {
+            [self release];
             PyErr_Clear();
-            rval = NULL;
+            return 0;
         }
+        rval = (void*)buffer;
+      }
+#endif
 
-        rval = buffer;
     PyObjC_END_WITH_GIL
     return rval;
 }
