@@ -1,6 +1,6 @@
-/* Copyright (c) 1996,97 by Lele Gaifax.  All Rights Reserved
+/* Copyright (c) 1996,97 by Lele Gaifax. All Rights Reserved
  * Copyright 2002, 2003 Ronald Oussoren, Jack Jansen
- * Copyright 2003-2014 Ronald Oussoren
+ * Copyright 2003-2017 Ronald Oussoren
  *
  * This software may be used and distributed freely for any purpose
  * provided that this notice is included unchanged on any and all
@@ -14,15 +14,15 @@
 
 #include <stdarg.h>
 
-#import  <Foundation/NSObject.h>
-#import  <Foundation/NSMethodSignature.h>
-#import  <Foundation/NSInvocation.h>
-#import  <Foundation/NSString.h>
-#import  <Foundation/NSDictionary.h>
-#import  <Foundation/NSEnumerator.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSMethodSignature.h>
+#import <Foundation/NSInvocation.h>
+#import <Foundation/NSString.h>
+#import <Foundation/NSDictionary.h>
+#import <Foundation/NSEnumerator.h>
 
 #if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_3
-#import  <Foundation/NSKeyValueObserving.h>
+#import <Foundation/NSKeyValueObserving.h>
 #endif
 
 #import "OC_PythonUnicode.h"
@@ -46,6 +46,8 @@ extern NSString * const NSUnknownKeyException; /* Radar #3336042 */
 -(id)initWithPyObject:(PyObject *) obj
 {
     PyObjC_BEGIN_WITH_GIL
+	if (PyLong_Check(obj)) abort();
+
         if (pyObject) {
             PyObjC_UnregisterObjCProxy(pyObject, self);
         }
@@ -66,6 +68,11 @@ extern NSString * const NSUnknownKeyException; /* Radar #3336042 */
 -(oneway void)release
 {
     /* See comment in OC_PythonUnicode */
+    if (unlikely(!Py_IsInitialized())) {
+        [super release];
+        return;
+    }
+
     PyObjC_BEGIN_WITH_GIL
         [super release];
     PyObjC_END_WITH_GIL
@@ -74,6 +81,11 @@ extern NSString * const NSUnknownKeyException; /* Radar #3336042 */
 
 -(void)dealloc
 {
+    if (unlikely(!Py_IsInitialized())) {
+        [super dealloc];
+        return;
+    }
+
     PyObjC_BEGIN_WITH_GIL
         PyObjC_UnregisterObjCProxy(pyObject, self);
         Py_CLEAR(pyObject);
@@ -214,7 +226,7 @@ check_argcount (PyObject *pymethod, Py_ssize_t argcount)
 static PyObject*
 get_method_for_selector(PyObject *obj, SEL aSelector)
 {
-    const char*  meth_name;
+    const char* meth_name;
     char pymeth_name[256];
     Py_ssize_t argcount;
     PyObject* pymethod;
@@ -241,7 +253,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return NULL;
     }
 
-    result =  check_argcount(pymethod, argcount);
+    result = check_argcount(pymethod, argcount);
     if (result == NULL) {
         Py_DECREF(pymethod);
     }
@@ -292,7 +304,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
 
 + (NSMethodSignature *) methodSignatureForSelector:(SEL) sel
 {
-    Method           m;
+    Method m;
 
     m = class_getClassMethod(self, sel);
     if (m) {
@@ -313,12 +325,12 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
      * an exception.
      */
 
-    char*           encoding;
-    PyObject*          pymethod;
-    PyCodeObject*      func_code;
-    Py_ssize_t         argcount;
-    Class           cls;
-    Method           m;
+    char* encoding;
+    PyObject* pymethod;
+    PyCodeObject* func_code;
+    Py_ssize_t argcount;
+    Class cls;
+    Method m;
 
     cls = object_getClass(self);
     m = class_getInstanceMethod(cls, sel);
@@ -378,8 +390,8 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(respondsToSelector:))){
-        SEL    sel;
-        BOOL    b;
+        SEL sel;
+        BOOL b;
 
         [invocation getArgument:&sel atIndex:2];
 
@@ -389,7 +401,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(classForKeyedArchiver))){
-        Class    c;
+        Class c;
 
         c = [self classForKeyedArchiver];
         [invocation setReturnValue:&c];
@@ -397,7 +409,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(classForArchiver))){
-        Class    c;
+        Class c;
 
         c = [self classForArchiver];
         [invocation setReturnValue:&c];
@@ -405,7 +417,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(classForCoder))){
-        Class    c;
+        Class c;
 
         c = [self classForCoder];
         [invocation setReturnValue:&c];
@@ -413,7 +425,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(classForPortCoder))){
-        Class    c;
+        Class c;
 
         c = [self classForPortCoder];
         [invocation setReturnValue:&c];
@@ -421,7 +433,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(replacementObjectForKeyedArchiver:))){
-        NSObject*    c;
+        NSObject* c;
         NSKeyedArchiver* archiver;
 
         [invocation getArgument:&archiver atIndex:2];
@@ -431,7 +443,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(replacementObjectForArchiver:))){
-        NSObject*    c;
+        NSObject* c;
         NSArchiver* archiver;
 
         [invocation getArgument:&archiver atIndex:2];
@@ -441,7 +453,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(replacementObjectForCoder:))){
-        NSObject*    c;
+        NSObject* c;
         NSCoder* archiver;
 
         [invocation getArgument:&archiver atIndex:2];
@@ -451,7 +463,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(replacementObjectForPortCoder:))){
-        NSObject*    c;
+        NSObject* c;
         NSPortCoder* archiver;
 
         [invocation getArgument:&archiver atIndex:2];
@@ -461,7 +473,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(copy))) {
-        NSObject*    c;
+        NSObject* c;
 
         c = [self copy];
         [invocation setReturnValue:&c];
@@ -469,7 +481,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         return YES;
 
     } else if (sel_isEqual(aSelector, @selector(copyWithZone:))) {
-        NSObject*    c;
+        NSObject* c;
         NSZone* zone;
 
         [invocation getArgument:&zone atIndex:2];
@@ -526,7 +538,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
         for (i=2; i< argcount; i++) {
             const char *argtype;
             char *argbuffer;
-            Py_ssize_t  argsize;
+            Py_ssize_t argsize;
             PyObject *pyarg;
 
             argtype = [msign getArgumentTypeAtIndex:i];
@@ -615,7 +627,7 @@ get_method_for_selector(PyObject *obj, SEL aSelector)
     PyObject* rval;
 
     PyObjC_BEGIN_WITH_GIL
-        rval =  PyObjCClass_New([OC_PythonObject class]);
+        rval = PyObjCClass_New([OC_PythonObject class]);
         *cookie = 0;
     PyObjC_END_WITH_GIL
 
@@ -675,7 +687,7 @@ getModuleFunction(char* modname, char* funcname)
  */
 -(id)valueForKey:(NSString*) key
 {
-static  PyObject* getKeyFunc = NULL;
+static PyObject* getKeyFunc = NULL;
 
     PyObject* keyName;
     PyObject* val;
@@ -727,7 +739,7 @@ static  PyObject* getKeyFunc = NULL;
 
 -(void)setValue:value forKey:(NSString*) key
 {
-static  PyObject* setKeyFunc = NULL;
+static PyObject* setKeyFunc = NULL;
 
     PyObject* keyName;
     PyObject* pyValue;
@@ -792,7 +804,7 @@ static  PyObject* setKeyFunc = NULL;
 
 -(id)valueForKeyPath: (NSString*) keyPath
 {
-static  PyObject* getKeyFunc = NULL;
+static PyObject* getKeyFunc = NULL;
 
     PyObject* keyName;
     PyObject* val;
@@ -838,7 +850,7 @@ static  PyObject* getKeyFunc = NULL;
 
 -(void)setValue: value forKeyPath: (NSString*) keyPath
 {
-static  PyObject* setKeyFunc = NULL;
+static PyObject* setKeyFunc = NULL;
 
     PyObject* keyName;
     PyObject* pyValue;
@@ -1071,9 +1083,23 @@ static  PyObject* setKeyFunc = NULL;
                 PyObjC_GIL_FORWARD_EXC();
             }
 
-            SET_FIELD(pyObject, v);
+            /* To make life more interesting the correct proxy
+             * type for 'v' might not be OC_PythonObject, in particular
+             * when introducing new proxy types in new versions
+             * of PyObjC, and in some error cases.
+             */
+            NSObject* temp;
+            if (depythonify_python_object(v, &temp) == -1) {
+                Py_DECREF(v);
+                PyObjC_GIL_FORWARD_EXC();
+            }
 
-            self = PyObjC_FindOrRegisterObjCProxy(pyObject, self);
+            if (temp != (NSObject*)self) {
+                [temp retain];
+                [self release];
+                self = (OC_PythonObject*)temp;
+            }
+            Py_DECREF(pyObject);
 
         PyObjC_END_WITH_GIL
 
