@@ -1,5 +1,5 @@
-/* Copyright (c) 1996,97 by Lele Gaifax.  All Rights Reserved
- * With various updates by Ronald Oussoren and others ((C) 2002-2014)
+/* Copyright (c) 1996,97 by Lele Gaifax. All Rights Reserved
+ * With various updates by Ronald Oussoren and others ((C) 2002-2017)
  *
  * This software may be used and distributed freely for any purpose
  * provided that this notice is included unchanged on any and all
@@ -88,7 +88,18 @@ PyObjCPointer_New(void *p, const char *t)
             "pointer of type %s", t);
         return NULL;
     }
-    NSLog(@"PyObjCPointer created: at %p of type %s", p, t);
+
+#if PY_MAJOR_VERSION == 3
+    if (PyErr_WarnFormat(PyObjCExc_ObjCPointerWarning, 0, "PyObjCPointer created: at %p of type %s", p, t) == -1) {
+    	return NULL;
+    }
+#else
+    char buf[256];
+    snprintf(buf, 256, "PyObjCPointer created: at %p of type %s", p, t);
+    if (PyErr_Warn(PyObjCExc_ObjCPointerWarning, buf) == -1) {
+    	return NULL;
+    }
+#endif
 
     if (size == -1) {
         return NULL;
