@@ -18,17 +18,17 @@
  */
 
 enum {
-    BLOCK_HAS_COPY_DISPOSE =  (1 << 25),
-    BLOCK_IS_GLOBAL        =  (1 << 28),
-    BLOCK_HAS_STRET        =  (1 << 29),
-    BLOCK_HAS_SIGNATURE    =  (1 << 30)
+    BLOCK_HAS_COPY_DISPOSE = (1 << 25),
+    BLOCK_IS_GLOBAL        = (1 << 28),
+    BLOCK_HAS_STRET        = (1 << 29),
+    BLOCK_HAS_SIGNATURE    = (1 << 30)
 };
 
 /*
  * End of definitions.
  */
 
-static Class gStackBlockClass = nil;
+static Class gGlobalBlockClass = nil;
 
 struct block_descriptor {
     unsigned long int reserved;
@@ -46,8 +46,8 @@ struct block_descriptor_basic {
 
 struct block_literal {
     void* isa;
-    int   flags;
-    int   reserved;
+    int flags;
+    int reserved;
     void (*invoke)(void*, ...);
     struct block_descriptor* descriptor;
     PyObject* invoke_cleanup;
@@ -114,7 +114,7 @@ static struct block_descriptor gDescriptorTemplate = {
 };
 
 static struct block_literal gLiteralTemplate = {
-    0,     /* ISA */
+    0, /* ISA */
     BLOCK_HAS_COPY_DISPOSE,
     0,
     0,
@@ -151,8 +151,8 @@ PyObjCBlock_Call(PyObject* module __attribute__((__unused__)), PyObject* func_ar
     unsigned char* argbuf = NULL;
     ffi_type* arglist[MAX_ARGCOUNT];
     void* values[MAX_ARGCOUNT];
-    void* byref[MAX_ARGCOUNT] =  { 0 };
-    struct byref_attr byref_attr[MAX_ARGCOUNT] =  { {0, 0} };
+    void* byref[MAX_ARGCOUNT] = { 0 };
+    struct byref_attr byref_attr[MAX_ARGCOUNT] = { {0, 0} };
     ffi_cif cif;
     PyObject* retval;
 
@@ -186,7 +186,7 @@ PyObjCBlock_Call(PyObject* module __attribute__((__unused__)), PyObject* func_ar
     argbuf_len = PyObjCRT_SizeOfReturnType(signature->rettype->type);
     argbuf_len = align(argbuf_len, sizeof(void*));
 
-    int useStret =  PyObjCRT_ResultUsesStret(signature->rettype->type);
+    int useStret = PyObjCRT_ResultUsesStret(signature->rettype->type);
     if (useStret == -1) {
         goto error;
     }
@@ -358,7 +358,7 @@ PyObjCBlock_Create(PyObjCMethodSignature* signature, PyObject* callable)
 {
     struct block_literal* block;
 
-    if (gStackBlockClass == NULL) {
+    if (gGlobalBlockClass == NULL) {
         PyErr_SetString(PyObjCExc_Error, "Blocks not supported on this platform");
         return NULL;
     }
@@ -372,16 +372,18 @@ PyObjCBlock_Create(PyObjCMethodSignature* signature, PyObject* callable)
     *block = gLiteralTemplate;
     block->descriptor = (struct block_descriptor*)(((char*)block) + sizeof(struct block_literal));
     *(block->descriptor) = *(gLiteralTemplate.descriptor);
-    if (signature->signature == NULL) {
-        signature->signature = block_signature(signature);
-        if (signature->signature == NULL) {
-            PyMem_Free(block);
-            return NULL;
-        }
+
+    /* The value of "signature->signature" cannot be trusted, it
+     * contains the raw signature without any updates from metadata.
+     * Futhermore the value is bogus for block signatures in metadata.
+     */
+    block->descriptor->signature = block_signature(signature);
+    if (block->descriptor->signature == NULL) {
+        PyMem_Free(block);
+        return NULL;
     }
-    block->descriptor->signature = signature->signature;
     block->flags |= BLOCK_HAS_SIGNATURE;
-    block->isa = gStackBlockClass;
+    block->isa = gGlobalBlockClass;
     block->invoke = PyObjCFFI_MakeBlockFunction(signature, callable);
     if (block->invoke == NULL) {
         PyMem_Free(block);
@@ -403,21 +405,86 @@ PyObjCBlock_Release(void* _block)
 {
     struct block_literal* block = (struct block_literal*)_block;
     Py_CLEAR(block->invoke_cleanup);
+    PyMem_Free((void*)(block->descriptor->signature));
     PyMem_Free(block);
 }
 
 
-int
-PyObjCBlock_Setup(void)
-{
-    gStackBlockClass = objc_lookUpClass("__NSGlobalBlock__");
-
-    return 0;
-}
-
-
 _block_func_ptr
 PyObjCBlock_GetFunction(void* block)
 {
     return ((struct block_literal*)block)->invoke;
 }
+
+/*
+ * Support for converting blocks to python objects.
+ */
+
+static PyObject*
+pyobjc_PythonObject(NSObject* self, SEL _sel __attribute__((__unused__)))
+{
+    PyObject *rval;
+
+    /* Stack blocks are allocated on the stack and cause problems with
+     * Python's garbage collections. Therefore uncondationally copy them,
+     * which converts them to dynamicly allocated blocks.
+     */
+    self = [self copy];
+
+    rval = PyObjC_FindPythonProxy(self);
+
+    rval = (PyObject *)PyObjCObject_New(self, PyObjCObject_kDEFAULT, YES);
+    [self release];
+    if (rval == NULL) {
+        return NULL;
+    }
+
+    if (rval != NULL) {
+        PyObjC_RegisterPythonProxy(self, rval);
+    }
+
+    return rval;
+}
+
+static PyObject*
+pyobjc_PythonTransient(NSObject* self, SEL _sel __attribute__((__unused__)), int* cookie)
+{
+    /* Stack blocks are allocated on the stack and cause problems with
+     * Python's garbage collections. Therefore uncondationally copy them,
+     * which converts them to dynamicly allocated blocks.
+     */
+
+    self = [self copy];
+
+    PyObject* result = PyObjC_FindPythonProxy(self);
+    if (result) {
+        *cookie = 0;
+        return result;
+    }
+
+    *cookie = 1;
+    result = PyObjCObject_New(self, PyObjCObject_kDEFAULT, YES);
+    [self release];
+    return result;
+}
+
+int
+PyObjCBlock_Setup(void)
+{
+    Class StackBlock;
+    gGlobalBlockClass = objc_lookUpClass("__NSGlobalBlock__");
+
+    StackBlock = objc_lookUpClass("__NSStackBlock__");
+    if (StackBlock != Nil) {
+        if (!class_addMethod(StackBlock, @selector(__pyobjc_PythonObject__), (IMP)pyobjc_PythonObject, "^{_object}@:")) {
+            PyErr_SetString(PyObjCExc_InternalError, "Cannot initialize block support");
+            return -1;
+        }
+        if (!class_addMethod(StackBlock, @selector(__pyobjc_PythonTransient__:), (IMP)pyobjc_PythonTransient, "^{_object}@:^i")) {
+            PyErr_SetString(PyObjCExc_InternalError, "Cannot initialize block support");
+            return -1;
+        }
+    }
+
+    return 0;
+}
