@@ -51,8 +51,16 @@ PyObjC_TryCreateCFProxy(NSObject* value)
         PyTypeObject* tp;
 
         cfid = PyInt_FromLong(CFGetTypeID((CFTypeRef)value));
+#if PY_MAJOR_VERSION == 3
         tp = (PyTypeObject*)PyDict_GetItem(gTypeid2class, cfid);
         Py_DECREF(cfid);
+        if (tp == NULL && PyErr_Occurred()) {
+            return NULL;
+        }
+#else
+        tp = (PyTypeObject*)PyDict_GetItem(gTypeid2class, cfid);
+        Py_DECREF(cfid);
+#endif
 
         if (tp != NULL) {
             rval = tp->tp_alloc(tp, 0);
@@ -132,7 +140,16 @@ PyObjCCFType_New(char* name, char* encoding, CFTypeID typeID)
         return NULL;
     }
 
+#if PY_MAJOR_VERSION == 3
+    result = PyDict_GetItemWithError(gTypeid2class, cf);
+    if (result == NULL && PyErr_Occurred()) {
+        Py_DECREF(cf);
+        return NULL;
+    }
+#else
+
     result = PyDict_GetItem(gTypeid2class, cf);
+#endif
     if (result != NULL) {
         /* This type is the same as an already registered type,
          * return that type
@@ -267,10 +284,19 @@ PyObject*
 PyObjCCF_NewSpecial(char* typestr, void* datum)
 {
     PyObject* rval = NULL;
+#if PY_MAJOR_VERSION == 3
+    PyObject* v = PyDict_GetItemStringWithError(PyObjC_TypeStr2CFTypeID, typestr);
+
+#else
     PyObject* v = PyDict_GetItemString(PyObjC_TypeStr2CFTypeID, typestr);
+#endif
+
     CFTypeID typeid;
 
     if (v == NULL) {
+        if (PyErr_Occurred()) {
+            return NULL;
+        }
         PyErr_Format(PyExc_ValueError, "Don't know CF type for typestr '%s', cannot create special wrapper", typestr);
         return NULL;
     }
@@ -284,8 +310,17 @@ PyObjCCF_NewSpecial(char* typestr, void* datum)
         PyTypeObject* tp;
 
         cfid = PyInt_FromLong(typeid);
+#if PY_MAJOR_VERSION == 3
+        tp = (PyTypeObject*)PyDict_GetItemWithError(gTypeid2class, cfid);
+        Py_DECREF(cfid);
+
+        if (tp == NULL && PyErr_Occurred()) {
+            return NULL;
+        }
+#else
         tp = (PyTypeObject*)PyDict_GetItem(gTypeid2class, cfid);
         Py_DECREF(cfid);
+#endif
 
         if (tp != NULL) {
             rval = tp->tp_alloc(tp, 0);
@@ -323,8 +358,16 @@ PyObjCCF_NewSpecial2(CFTypeID typeid, void* datum)
         PyTypeObject* tp;
 
         cfid = PyInt_FromLong(typeid);
+#if PY_MAJOR_VERSION == 3
+        tp = (PyTypeObject*)PyDict_GetItemWithError(gTypeid2class, cfid);
+        Py_DECREF(cfid);
+        if (tp == NULL && PyErr_Occurred()) {
+            return NULL;
+        }
+#else
         tp = (PyTypeObject*)PyDict_GetItem(gTypeid2class, cfid);
         Py_DECREF(cfid);
+#endif
 
         if (tp != NULL) {
             rval = tp->tp_alloc(tp, 0);
