@@ -118,6 +118,7 @@ static char* keywords[] = { "name", "supers", "selectors", NULL };
         }
     }
 
+#if (MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_7)
     if (objc_allocateProtocol == NULL) {
         /* Protocol creation API is new in OSX 10.7, can will be weak-linked when
          * building on OSX 10.7 with a 10.6 deployment target.
@@ -126,6 +127,7 @@ static char* keywords[] = { "name", "supers", "selectors", NULL };
         PyErr_SetString(PyObjCExc_Error, "Cannot create formal protocols on this platform");
         return NULL;
     }
+#endif
 
     theProtocol = objc_allocateProtocol(name);
     if (theProtocol == NULL) {
@@ -239,7 +241,7 @@ append_method_list(PyObject* lst, Protocol* protocol, BOOL isRequired, BOOL isIn
             "{sysysO}",
 #endif /* PY_MAJOR_VERSION == 3 */
             "selector", sel_getName(methods[i].name),
-            "typestr",  buf,
+            "typestr", buf,
             "required", isRequired?Py_True:Py_False);
         if (item == NULL) {
             free(methods);
@@ -566,7 +568,7 @@ do_verify(
             if (is_required) {
                 PyErr_Format(PyExc_TypeError,
                     "class %s does not full implement protocol "
-                    "%s: no implementation for %s",
+                    "%s: no implementation for '%s'",
                     name,
                     protocol_name,
                     sel_getName(descr->name));
@@ -582,7 +584,7 @@ do_verify(
         if (!PyObjCSelector_IsClassMethod(meth)) {
             PyErr_Format(PyExc_TypeError,
                 "class %s does not correctly implement "
-                "protocol %s: method %s is not a "
+                "protocol %s: method '%s' is not a "
                 "class method",
                 name,
                 protocol_name,
@@ -595,7 +597,7 @@ do_verify(
         if (PyObjCSelector_IsClassMethod(meth)) {
             PyErr_Format(PyExc_TypeError,
                 "class %s does not correctly implement "
-                "protocol %s: method %s is not an "
+                "protocol %s: method '%s' is not an "
                 "instance method",
                 name,
                 protocol_name,
@@ -612,7 +614,7 @@ do_verify(
 
     PyErr_Format(PyExc_TypeError,
         "class %s does not correctly implement "
-        "protocol %s: the signature for method %s "
+        "protocol %s: the signature for method '%s' "
         "is %s instead of %s",
         name,
         protocol_name,
