@@ -9,7 +9,17 @@
 
 
 #if USE_TOOLBOX_OBJECT_GLUE
-#include "pymactoolbox.h"
+
+  /* As of the 10.12 SDK it is no longer safe to inlcude pymactoolbox.h
+   * (due to an include that can no longer be resolved). Therefore
+   * provide local declarations.
+   */
+  /*#include "pymactoolbox.h"*/
+
+extern int PyMac_GetFSRef(PyObject *, FSRef *);        /* argument parser for FSRef */
+extern PyObject *PyMac_BuildFSRef(FSRef *);            /* Convert FSRef to PyObject */
+extern PyObject *PyMac_Error(OSErr);                   /* Uses PyMac_GetOSErrException */
+
 #endif
 
 /*
@@ -35,7 +45,7 @@
 typedef struct {
     PyObject_HEAD
 
-    FSRef    ref;
+    FSRef ref;
 } PyObjC_FSRefObject;
 
 static PyObject*
