@@ -4,9 +4,18 @@
 #include "pyobjc.h"
 #import <CoreServices/CoreServices.h>
 
-
 #if USE_TOOLBOX_OBJECT_GLUE
-#include "pymactoolbox.h"
+  /* As of the 10.12 SDK it is no longer safe to inlcude pymactoolbox.h
+   * (due to an include that can no longer be resolved). Therefore provide
+   * local declarations.
+   */
+
+  /* #include "pymactoolbox.h" */
+
+extern PyObject *PyMac_Error(OSErr);                   /* Uses PyMac_GetOSErrException */
+extern int PyMac_GetFSSpec(PyObject *, FSSpec *);      /* argument parser for FSSpec */
+extern PyObject *PyMac_BuildFSSpec(FSSpec *);          /* Convert FSSpec to PyObject */
+
 #endif
 
 /*
@@ -32,7 +41,7 @@
 typedef struct {
     PyObject_HEAD
 
-    FSSpec    ref;
+    FSSpec ref;
 } PyObjC_FSSpecObject;
 
 static PyObject* fsspec_as_bytes(PyObject* ref, void* closure __attribute__((__unused__)))
