@@ -103,22 +103,20 @@ imp_NSData_bytes(
         Py_DECREF(result);
         *pretval = (void *)p;
         PyGILState_Release(state);
-        return;
 
     } else
 #endif /* PY_MAJOR_VERSION == 2 */
-
-    if (PyBytes_Check(result)) {
-        void* p;
-
-        p = PyBytes_AsString(result);
-        *pretval = (void*)p;
+    {
+        OCReleasedBuffer* temp = [[OCReleasedBuffer alloc] initWithPythonBuffer:result writable:NO];
+        if (temp == nil) {
+            *pretval = NULL;
+            goto error;
+        }
+        [temp autorelease];
+        *pretval=[temp buffer];
         PyGILState_Release(state);
-        return;
     }
-
-    PyErr_SetString(PyExc_ValueError, "No idea what to do with result.");
-    goto error;
+    return;
 
 error:
     Py_XDECREF(arglist);
@@ -214,11 +212,6 @@ imp_NSMutableData_mutableBytes(
     PyObjCObject_ReleaseTransient(pyself, cookie); pyself = NULL;
     if (result == NULL) goto error;
 
-    if (result == Py_None) {
-        Py_DECREF(result);
-        goto error;
-    }
-
     if (result == Py_None) {
         *pretval = NULL;
         Py_DECREF(result);
@@ -226,11 +219,13 @@ imp_NSMutableData_mutableBytes(
         return;
     }
 
-    void *p;
-    Py_ssize_t len;
-    if (PyObject_AsWriteBuffer(result, &p, &len) == -1) goto error;
-    Py_DECREF(result);
-    *pretval = (void *)p;
+    OCReleasedBuffer* temp = [[OCReleasedBuffer alloc] initWithPythonBuffer:result writable:YES];
+    if (temp == nil) {
+        *pretval = NULL;
+        goto error;
+    }
+    [temp autorelease];
+    *pretval=[temp buffer];
     PyGILState_Release(state);
     return;
 
