@@ -12,5 +12,9 @@ extern int IS_DECIMAL(const char* typestr);
 
 extern int PyObjC_number_to_decimal(PyObject* value, NSDecimal* outResult);
 
+extern PyObject* pythonify_authorizationitem(void* value);
+extern int depythonify_authorizationitem(PyObject* value, void* out);
+extern int IS_AUTHORIZATIONITEM(const char* typestr);
+
 #endif /* PyObjC_HELPERS_H */
 
