@@ -7,7 +7,7 @@ extern PyTypeObject PyObjCMethodSignature_Type;
 
 enum _PyObjC_PointerType
 #if __has_feature(objc_fixed_enum)
-	: unsigned char
+    : unsigned char
 #endif /* __has_feature(objc_fixed_enum) */
 {
     PyObjC_kPointerPlain = 0,
@@ -52,6 +52,7 @@ struct _PyObjCMethodSignature {
     unsigned char shortcut_signature:1;
     unsigned int shortcut_argbuf_size:12;
     int16_t arrayArg;
+    int     deprecated;
     struct _PyObjC_ArgDescr* rettype;
     struct _PyObjC_ArgDescr* argtype[1];
 };
@@ -70,11 +71,14 @@ PyObjC_NSMethodSignatureToTypeString(
 extern int
 PyObjC_registerMetaData(PyObject*, PyObject*, PyObject*);
 
+extern PyObject*
+PyObjC_copyMetadataRegistry(void);
+
 extern PyObject*
 PyObjCMethodSignature_AsDict(PyObjCMethodSignature* methinfo);
 
 #define PyObjCMethodSignature_FromSignature(sig, is_native) \
-	PyObjCMethodSignature_WithMetaData((sig), NULL, (is_native))
+    PyObjCMethodSignature_WithMetaData((sig), NULL, (is_native))
 
 
 #ifdef PyObjC_DEBUG
