@@ -1,5 +1,5 @@
-/* Copyright (c) 1996,97,98 by Lele Gaifax.  All Rights Reserved
- * Copyright (c) 2002-2014 Ronald Oussoren
+/* Copyright (c) 1996,97,98 by Lele Gaifax. All Rights Reserved
+ * Copyright (c) 2002-2017 Ronald Oussoren
  *
  * This software may be used and distributed freely for any purpose
  * provided that this notice is included unchanged on any and all
@@ -363,6 +363,7 @@ PyObjCRT_SkipTypeQualifiers(const char* type)
 const char *
 PyObjCRT_SkipTypeSpec(const char *type)
 {
+    const char* start_type = type;
     PyObjC_Assert(type != NULL, NULL);
 
     type = PyObjCRT_SkipTypeQualifiers(type);
@@ -422,43 +423,56 @@ PyObjCRT_SkipTypeSpec(const char *type)
 
         while (isdigit(*++type));
         type = PyObjCRT_SkipTypeSpec(type);
-        PyObjC_Assert(type == NULL || *type == _C_ARY_E, NULL);
+        if (type && *type != _C_ARY_E) {
+            PyErr_Format(PyObjCExc_InternalError, "Invalid array definition in type signature: %s", start_type);
+            return NULL;
+        }
         if (type) type++;
         break;
 
     case _C_STRUCT_B:
         /* skip name, and elements until closing '}'  */
-        while (*type != _C_STRUCT_E && *type++ != '=');
-        while (type && *type != _C_STRUCT_E) {
+        while (*type && *type != _C_STRUCT_E && *type++ != '=');
+        while (type && *type && *type != _C_STRUCT_E) {
             if (*type == '"') {
                 /* embedded field names */
                 type = strchr(type+1, '"');
                 if (type != NULL) {
                     type++;
                 } else {
+                    PyErr_Format(PyObjCExc_InternalError, "Invalid struct definition in type signature: %s", start_type);
                     return NULL;
                 }
             }
             type = PyObjCRT_SkipTypeSpec(type);
         }
+        if (type && *type != _C_STRUCT_E) {
+            PyErr_Format(PyObjCExc_InternalError, "Invalid struct definition in type signature: %s", start_type);
+            return NULL;
+        }
         if (type) type++;
         break;
 
     case _C_UNION_B:
         /* skip name, and elements until closing ')'  */
-        while (*type != _C_UNION_E && *type++ != '=');
-        while (type && *type != _C_UNION_E) {
+        while (*type && *type != _C_UNION_E && *type++ != '=');
+        while (type && *type && *type != _C_UNION_E) {
             if (*type == '"') {
                 /* embedded field names */
                 type = strchr(type+1, '"');
                 if (type != NULL) {
                     type++;
                 } else {
+                    PyErr_Format(PyObjCExc_InternalError, "Invalid union definition in type signature: %s", start_type);
                     return NULL;
                 }
             }
             type = PyObjCRT_SkipTypeSpec(type);
         }
+        if (type && *type != _C_UNION_E) {
+            PyErr_Format(PyObjCExc_InternalError, "Invalid union definition in type signature: %s", start_type);
+            return NULL;
+        }
         if (type) type++;
         break;
 
@@ -558,8 +572,8 @@ PyObjCRT_NextField(const char *type)
 
     case _C_STRUCT_B:
         /* skip name, and elements until closing '}'  */
-        while (*type != _C_STRUCT_E && *type++ != '=');
-        while (type && *type != _C_STRUCT_E) {
+        while (*type && *type != _C_STRUCT_E && *type++ != '=');
+        while (type && *type && *type != _C_STRUCT_E) {
             if (*type == '"') {
                 /* embedded field names */
                 type = strchr(type+1, '"');
@@ -582,13 +596,13 @@ PyObjCRT_NextField(const char *type)
                 "PyObjCRT_SkipTypeSpec: Got '0x%x' at end of struct encoding, expecting '0x%x'", *type, _C_STRUCT_E);
             return NULL;
         }
-        type++;
+        if (type) type++;
         break;
 
     case _C_UNION_B:
         /* skip name, and elements until closing ')'  */
-        while (*type != _C_UNION_E && *type++ != '=');
-        while (type && *type != _C_UNION_E) {
+        while (*type && *type != _C_UNION_E && *type++ != '=');
+        while (type && *type && *type != _C_UNION_E) {
             if (*type == '"') {
                 /* embedded field names */
                 type = strchr(type+1, '"');
@@ -606,12 +620,11 @@ PyObjCRT_NextField(const char *type)
                         "Unexpected NULL while parsing union encoding type");
             }
             return NULL;
-        } else if (unlikely(*type != _C_STRUCT_E)) {
+        } else if (unlikely(*type != _C_UNION_E)) {
             PyErr_Format(PyObjCExc_InternalError,
                 "PyObjCRT_SkipTypeSpec: Got '0x%x' at end of union encoding, expecting '0x%x'", *type, _C_UNION_E);
             return NULL;
         }
-        type++;
         break;
 
     case _C_PTR:
@@ -768,6 +781,7 @@ PyObjCRT_AlignOfType(const char *type)
     {
         Py_ssize_t maxalign = 0;
         type++;
+        while(*type != _C_STRUCT_E && *type++ != '=') /* do nothing */;
         while (*type != _C_UNION_E)
         {
             Py_ssize_t item_align = PyObjCRT_AlignOfType(type);
@@ -1196,6 +1210,9 @@ pythonify_c_struct(const char *type, void *datum)
     if (IS_DECIMAL(type)) {
         return pythonify_nsdecimal(datum);
     }
+    if (IS_AUTHORIZATIONITEM(type)) {
+        return pythonify_authorizationitem(datum);
+    }
 
     /* The compiler adds useless digits at the end of the signature */
     while (type_end != type_start+1 && type_end[-1] != _C_STRUCT_E) {
@@ -1275,7 +1292,7 @@ pythonify_c_struct(const char *type, void *datum)
 
             } else {
                 int r;
-                r = PySequence_SetItem(ret, itemidx, pyitem);
+                r = PyObjC_SetStructField(ret, itemidx, pyitem);
                 Py_DECREF(pyitem);
 
                 if (r == -1) {
@@ -1578,6 +1595,9 @@ depythonify_c_struct(const char *types, PyObject *arg, void *datum)
     if (strncmp(types, @encode(struct sockaddr), sizeof(@encode(struct sockaddr))-1) == 0) {
         return PyObjC_SockAddrFromPython(arg, datum);
     }
+    if (IS_AUTHORIZATIONITEM(types)) {
+        return depythonify_authorizationitem(arg, datum);
+    }
 
     /* Extract struck packing value, need better way to fetch this */
     pack = -1;
@@ -1627,16 +1647,20 @@ depythonify_c_struct(const char *types, PyObject *arg, void *datum)
         type = PyObjCRT_SkipTypeSpec(type);
     }
 
-    seq = PySequence_Fast(arg, "depythonifying struct, got no sequence");
+    if (PyObjCStruct_Check(arg)) {
+        seq = StructAsTuple(arg);
+    } else {
+        seq = PySequence_Fast(arg, "depythonifying struct, got no sequence");
+    }
     if (seq == NULL) {
         return -1;
     }
 
     if (nitems != PySequence_Fast_GET_SIZE(seq)) {
-        Py_DECREF(seq);
         PyErr_Format(PyExc_ValueError,
             "depythonifying struct of %"PY_FORMAT_SIZE_T"d members, got tuple of %"PY_FORMAT_SIZE_T"d",
-            nitems, PyTuple_Size(arg));
+            nitems, PySequence_Fast_GET_SIZE(seq));
+        Py_DECREF(seq);
         return -1;
     }
 
@@ -2357,7 +2381,7 @@ static const char uintType[] = { _C_UINT, 0 };
 #endif
 }
 
-static int
+int
 depythonify_python_object(PyObject* argument, id* datum)
 {
     PyObject* anObject;
@@ -2396,7 +2420,10 @@ depythonify_python_object(PyObject* argument, id* datum)
         PyErr_Clear();
     }
 
-    if (PyUnicode_Check(argument)) {
+    if (PyUnicode_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonUnicode unicodeWithPythonObject:argument];
+
+    } else if (PyUnicode_Check(argument)) {
         *datum = [OC_PythonUnicode unicodeWithPythonObject:argument];
 
     } else if (PyBool_Check(argument)) {
@@ -2407,20 +2434,41 @@ depythonify_python_object(PyObject* argument, id* datum)
         }
 
 #if PY_MAJOR_VERSION == 2
+    } else if (PyInt_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonNumber numberWithPythonObject:argument];
     } else if (PyInt_Check(argument)) {
         *datum = [OC_PythonNumber numberWithPythonObject:argument];
 #endif /* PY_MAJOR_VERSION == 2 */
 
+    } else if (PyFloat_CheckExact(argument) ||  PyLong_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonNumber numberWithPythonObject:argument];
+
     } else if (PyFloat_Check(argument) || PyLong_Check(argument)) {
         *datum = [OC_PythonNumber numberWithPythonObject:argument];
 
+    } else if (PyList_CheckExact(argument) || PyTuple_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonArray arrayWithPythonObject:argument];
+
     } else if (PyList_Check(argument) || PyTuple_Check(argument)) {
         *datum = [OC_PythonArray arrayWithPythonObject:argument];
 
+    } else if (PyDict_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonDictionary dictionaryWithPythonObject:argument];
+
     } else if (PyDict_Check(argument)) {
         *datum = [OC_PythonDictionary dictionaryWithPythonObject:argument];
 
 #if PY_MAJOR_VERSION == 2
+    } else if (PyString_CheckExact(argument)) {
+        if (!PyObjC_StrBridgeEnabled) {
+            if (PyErr_Warn(PyObjCStrBridgeWarning, "use unicode(str, encoding) for NSString")) {
+                *datum = nil;
+                return -1;
+            }
+        }
+
+        *datum = [OC_BuiltinPythonString stringWithPythonObject:argument];
+
     } else if (PyString_Check(argument)) {
         if (!PyObjC_StrBridgeEnabled) {
             if (PyErr_Warn(PyObjCStrBridgeWarning, "use unicode(str, encoding) for NSString")) {
@@ -2432,9 +2480,25 @@ depythonify_python_object(PyObject* argument, id* datum)
         *datum = [OC_PythonString stringWithPythonObject:argument];
 #endif /* PY_MAJOR_VERSION == 2 */
 
-    } else if (PyObject_CheckReadBuffer(argument)) {
+#if PY_MAJOR_VERSION == 3
+    } else if (PyBytes_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonData dataWithPythonObject:argument];
+
+#endif /* PY_MAJOR_VERSION == 3 */
+
+    } else if (PyObject_CheckBuffer(argument)
+#if PY_MAJOR_VERSION == 2
+            || PyObject_CheckReadBuffer(argument)
+#endif
+            ) {
         *datum = [OC_PythonData dataWithPythonObject:argument];
 
+    } else if (PyAnySet_CheckExact(argument)) {
+        *datum = [OC_BuiltinPythonSet setWithPythonObject:argument];
+
+    } else if (PyAnySet_Check(argument)) {
+        *datum = [OC_PythonSet setWithPythonObject:argument];
+
     } else if (PyObjCFormalProtocol_Check(argument)) {
         *datum = PyObjCFormalProtocol_GetProtocol(argument);
         return 0;
@@ -2659,9 +2723,31 @@ depythonify_c_value(const char *type, PyObject *argument, void *datum)
         return 0;
 
     case _C_UNICHAR:
+#if PY_VERSION_HEX < 0x03030000
         if (PyUnicode_Check(argument) && PyUnicode_GetSize(argument) == 1) {
             *(UniChar*)datum = (UniChar)(*PyUnicode_AsUnicode(argument));
             return 0;
+#else /* PY_VERSION_HEX >= 0x03030000 */
+        if (PyUnicode_Check(argument) && PyUnicode_GetLength(argument) == 1) {
+
+            /* Need to guard against values outside of the BMP, which cannot be
+             * converted to UniChar
+             */
+            switch (PyUnicode_KIND(argument)) {
+            case PyUnicode_1BYTE_KIND:
+            case PyUnicode_2BYTE_KIND:
+                break;
+
+            default:
+                PyErr_Format(PyExc_ValueError, "Expecting string of length 1, got a '%s'",
+                    Py_TYPE(argument)->tp_name);
+                return -1;
+            }
+            *(UniChar*)datum = (UniChar)PyUnicode_ReadChar(argument, 0);
+            return 0;
+
+#endif /* PY_VERSION_HEX >= 0x03030000 */
+
 #if PY_MAJOR_VERSION == 2
         } else if (PyString_Check(argument)) {
             PyObject* u = PyUnicode_FromObject(argument);
