@@ -24,7 +24,7 @@ static char* keywords[] = { "count", NULL };
     PyObjC_VarList* self = (PyObjC_VarList*)_self;
 
     Py_ssize_t i, length;
-    PyObject*  result;
+    PyObject* result;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "n", keywords, &length)) {
         return NULL;
@@ -46,12 +46,61 @@ static char* keywords[] = { "count", NULL };
     return result;
 }
 
+PyDoc_STRVAR(object_as_buffer_doc,
+    "as_buffer(count)\n"
+    CLINIC_SEP
+    "\n"
+    "Return a memoryview referencing the memory for the first ``count`` "
+    "elements of this list."
+);
+
+static PyObject*
+object_as_buffer(PyObject* _self, PyObject* args, PyObject* kwds)
+{
+static char* keywords[] = { "count", NULL };
+
+    PyObjC_VarList* self = (PyObjC_VarList*)_self;
+
+    Py_ssize_t buffer_size, length;
+    Py_buffer info;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "n", keywords, &length)) {
+        return NULL;
+    }
+
+    if (length >= PY_SSIZE_T_MAX / self->itemsize) {
+        /* Calculating the buffer size would overflow */
+        PyErr_SetString(PyExc_OverflowError, "Buffer too long");
+        return NULL;
+    }
+
+    buffer_size = length * self->itemsize;
+
+    if (PyBuffer_FillInfo(&info, _self, self->array, buffer_size, 0, PyBUF_FULL) < 0) {
+        return NULL;
+    }
+
+    return PyMemoryView_FromBuffer(&info);
+}
 
 static PyObject*
 object__getitem__(PyObject* _self, Py_ssize_t idx)
 {
     PyObjC_VarList* self = (PyObjC_VarList*)_self;
 
+    if (idx < 0) {
+        /* Indeterminate size, cannot access from the 'end' */
+        PyErr_SetString(PyExc_ValueError, "Negative indexes are not supported");
+        return NULL;
+    }
+
+    if (idx >= PY_SSIZE_T_MAX / self->itemsize) {
+        /* Interger overflow, index cannot be correct */
+        PyErr_Format(PyExc_IndexError, "Index '%"PY_FORMAT_SIZE_T"d' out of range", idx);
+        return NULL;
+    }
+
+
     return pythonify_c_value(VARLIST_TYPE(self), ((unsigned char*)self->array) + (idx * self->itemsize));
 }
 
@@ -74,7 +123,7 @@ object__getslice__(PyObject* _self, Py_ssize_t start, Py_ssize_t stop)
     result = PyTuple_New(stop - start);
 
     for (idx = start; idx < stop; idx++) {
-        PyObject* v =  pythonify_c_value(
+        PyObject* v = pythonify_c_value(
             VARLIST_TYPE(self),
             ((unsigned char*)self->array) + (idx * self->itemsize));
         if (v == NULL) {
@@ -116,7 +165,7 @@ object__setslice__(PyObject* _self, Py_ssize_t start, Py_ssize_t stop, PyObject*
     }
 
     for (idx = start; idx < stop; idx++) {
-        PyObject* v =  PySequence_Fast_GET_ITEM(seq, idx-start);
+        PyObject* v = PySequence_Fast_GET_ITEM(seq, idx-start);
         int r = depythonify_c_value(
             VARLIST_TYPE(self),
             v,
@@ -135,6 +184,18 @@ object__setitem__(PyObject* _self, Py_ssize_t idx, PyObject* value)
 {
     PyObjC_VarList* self = (PyObjC_VarList*)_self;
 
+    if (idx < 0) {
+        /* Indeterminate size, cannot access from the 'end' */
+        PyErr_SetString(PyExc_ValueError, "Negative indexes are not supported");
+        return -1;
+    }
+
+    if (idx >= PY_SSIZE_T_MAX / self->itemsize) {
+        /* Interger overflow, index cannot be correct */
+        PyErr_Format(PyExc_IndexError, "Index '%"PY_FORMAT_SIZE_T"d' out of range", idx);
+        return -1;
+    }
+
     return depythonify_c_value(VARLIST_TYPE(self), value, ((unsigned char*)self->array) + (idx * self->itemsize));
 }
 
@@ -267,7 +328,7 @@ object_ass_subscript(PyObject* self, PyObject* item, PyObject* value)
     }
 }
 
-static PyMappingMethods  object_tp_as_mapping = {
+static PyMappingMethods object_tp_as_mapping = {
     .mp_subscript     = object_subscript,
     .mp_ass_subscript = object_ass_subscript
 };
@@ -320,6 +381,12 @@ static PyMethodDef object_methods[] = {
         .ml_flags   = METH_VARARGS|METH_KEYWORDS,
         .ml_doc     = object_as_tuple_doc
     },
+    {
+        .ml_name    = "as_buffer",
+        .ml_meth    = (PyCFunction)object_as_buffer,
+        .ml_flags   = METH_VARARGS|METH_KEYWORDS,
+        .ml_doc     = object_as_buffer_doc
+    },
     {
         .ml_name    = NULL /* SENTINEL */
     }
