@@ -1,13 +1,17 @@
 from PyObjCTools.TestSupport import *
 import objc
 import pickle
-import collections
 import sys
 
 NSObject = objc.lookUpClass('NSObject')
 NSIndexSet = objc.lookUpClass('NSIndexSet')
 NSMutableIndexSet = objc.lookUpClass('NSMutableIndexSet')
 
+if sys.version_info[0] == 3:
+    import collections.abc as collections_abc
+else:
+    import collections as collections_abc
+
 class TestArrayPropertyHelper (NSObject):
     array = objc.array_property()
     array2 = objc.array_property()
@@ -25,7 +29,7 @@ class TestArrayProperty (TestCase):
         o = TestArrayPropertyHelper.alloc().init()
 
         v = o.array
-        self.assertIsInstance(v, collections.MutableSequence)
+        self.assertIsInstance(v, collections_abc.MutableSequence)
 
         self.assertEqual(len(v), 0)
 
@@ -750,7 +754,7 @@ class TestArrayProperty (TestCase):
         o.array = [1,2,3]
         v = o.array
         self.assertEqual(v.count('a'), 0)
-        self.assertEqual(list(v.__reversed__()), [3,2,1]) 
+        self.assertEqual(list(v.__reversed__()), [3,2,1])
 
         self.assertRaises(AttributeError, getattr, o.array, 'nosuchattribute')
 
