@@ -2,6 +2,7 @@ from PyObjCTools.TestSupport import *
 
 import objc
 import sys
+import warnings
 
 #try:
 #    from  Foundation import NSRange
@@ -94,7 +95,9 @@ class TestBasicDescriptors (TestCase):
         self.assertRaises(TypeError, objc.namedSelector(b"foo:bar:", b"q@:qq"), 42)
 
     def testNamedselector(self):
-        with filterWarnings("ignore", RuntimeWarning):
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
+
             @objc.namedselector(b'foo:bar:')
             def mymethod(self, a, b):
                 pass
@@ -463,10 +466,11 @@ class TestBasicDescriptors (TestCase):
         self.assertEqual(validateColor_error_.signature, objc._C_NSBOOL + b'@:N^@o^@')
 
     def test_Accessor(self):
-        with filterWarnings("ignore", DeprecationWarning):
+        with warnings.catch_warnings():
             # NOTE: the optional type argument is tested through the typedAccessor function
 
             # Basic properties:
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
 
             @objc.Accessor
             def color(self):
@@ -649,22 +653,24 @@ class TestBasicDescriptors (TestCase):
                 pass
 
     def test_signature(self):
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
 
-        @objc.signature(b"d@:ii")
-        def myMethod_arg_(self, a, b):
-            pass
+            @objc.signature(b"d@:ii")
+            def myMethod_arg_(self, a, b):
+                pass
 
-        self.assertIsInstance(myMethod_arg_, objc.selector)
-        self.assertEqual(myMethod_arg_.signature, b'd@:ii')
-        self.assertEqual(myMethod_arg_.selector, b'myMethod:arg:')
+            self.assertIsInstance(myMethod_arg_, objc.selector)
+            self.assertEqual(myMethod_arg_.signature, b'd@:ii')
+            self.assertEqual(myMethod_arg_.selector, b'myMethod:arg:')
 
-        @objc.signature(b'q@:@q', selector=b'foo:bar:')
-        def method(self, a, b):
-            pass
+            @objc.signature(b'q@:@q', selector=b'foo:bar:')
+            def method(self, a, b):
+                pass
 
-        self.assertIsInstance(method, objc.selector)
-        self.assertEqual(method.signature, b'q@:@q')
-        self.assertEqual(method.selector, b'foo:bar:')
+            self.assertIsInstance(method, objc.selector)
+            self.assertEqual(method.signature, b'q@:@q')
+            self.assertEqual(method.selector, b'foo:bar:')
 
 if __name__ == "__main__":
     main()
