@@ -1,6 +1,5 @@
 from PyObjCTools.TestSupport import *
 import objc
-import warnings
 import sys
 import platform
 
@@ -31,6 +30,10 @@ class TestInformalProtocols(TestCase):
 
     def testIncompleteClass(self):
         self.assertRaises(TypeError, self.doIncompleteClass)
+        self.assertRaises(objc.error, objc.lookUpClass, 'ProtoClass2')
+
+        for cls in objc.getClassList():
+            self.assertNotEqual(cls.__name__, 'ProtoClass2')
 
 
     @onlyIf(sys.version_info[:2] < (3,2), "not valid for python 3.3 and later")
@@ -117,6 +120,16 @@ if (sys.maxsize < 2 ** 32 or platform.mac_ver()[0] >= '10.7') and sys.version_in
         # Implement unittests for formal protocols here.
         #
 
+        @onlyPython2
+        def testInheritedProtocol(self):
+            class MyClassImplementingNSObject(NSObject, objc.protocolNamed("OC_TestProtocol2")):
+                def method(self): return 1
+
+                @classmethod
+                def classMethod(self):
+                    return 2
+            self.assertTrue(MyClassImplementingNSObject.conformsToProtocol_(objc.protocolNamed("OC_TestProtocol2")))
+
         def testImplementAnotherObject(self):
             anObject = NSObject.alloc().init()
 
