@@ -7,7 +7,6 @@ from PyObjCTools.TestSupport import *
 
 import objc
 import operator
-import collections
 NSSet = objc.lookUpClass('NSSet')
 NSMutableSet = objc.lookUpClass('NSMutableSet')
 
@@ -23,11 +22,16 @@ if sys.version_info[0] == 3:
     def xrange(*args):
         return list(range(*args))
 
+    import collections.abc as collections_abc
+
+else:
+    import collections as collections_abc
+
 
 class TestPyObjCSet (TestCase):
     def test_reverse_operator(self):
 
-        class MySet (collections.Set):
+        class MySet (collections_abc.Set):
             def __init__(self, init=()):
                 self._value = list(init)
 
